.. MySmile documentation master file, created by
   sphinx-quickstart on Mon Feb  3 12:41:03 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

###################################   
Welcome to MySmile's documentation!
###################################

Contents:

.. toctree::
   :numbered:
   :maxdepth: 2
   :titlesonly:
   
   Getting started/index
   Technical Specifications/index
   Themes/index
   REST API/index
   Frequently Asked Questions
   glossary
